/* Created 27 November 2010.

This file use the data marriage_level.dta and creates "Figure 4: Pre-WWI matching was assortative" 
for "Marrying Up: The role of sex ratio in assortative matching".
*/

#delimit ;

* set this folder path to the directory that contains the file marriage_level.dta;
local folder "~/Documents";

version 11.1;
set more off;
clear all;
cd "`folder'";
set matsize 800;
set memory 40M;
capture log close;
log using figure4.log, replace;



*************************************************************************************;
* Panel A: Class defined by own occupation 
*************************************************************************************;

capture erase condif.mmat;

local classesnm = 7; 
local classes = 8; 
local classesm1 = 6; 

clear mata;
use marriage_level, clear;
keep if year<=1914;

keep clgr clbr;
order clgr clbr;
drop if clgr>=. | clbr>=.;
save tempmain2, replace;


*** Simulation;

mata;

// Create a matrix called actual with groom classes in column 1 and bride classes in column 2;
actual = st_data(.,.);

// Define parameters for the simulation;
classesnm = 7; // the number of occupation classes excluding missing; //#####;
reps = 1000; //  the number of repetitions for the simulation; //#####;
obs = rows(actual); // the number of bride-groom pairs in each rep;

uniformseed(547543680);

// empty matrix to hold simulation proportions of grooms married to each type bride.  Rows are reps, 
	//cols are g1b1, g1b2,... g1b`classesnm', g2b1 etc;
simres = J(reps,classesnm^2,.);

// empty matrix to hold simulations proportions of class differences: simulated proportions of couples; 
	//where groom class - bride class = 0, +/-1,  +/-(#non-missing clases-1);
// rows are reps, cols are grcl-brcl = -(#non-missing classes-1), -(#non-missing classes-1)+1, etc;
simdif = J(reps,2*classesnm-1,.); // number of cols;

// main simulation loop;
for (i=1; i<=reps; i++) {; // looping over reps;
	randgr = ceil(obs*uniform(obs,1)); // matrix of random integers 1 to obs, to indicate which groom 
		//class to extract for each simulated groom;
	randbr = ceil(obs*uniform(obs,1));
	sim = J(obs,2,.); // matrix of missing values to hold simulated groom and bride classes;

	// fill in matrix sim with simulated groom and bride classes;
	for (j=1; j<=obs; j++) {; // looping over observations;
		sim[j,1] = actual[randgr[j,1],1];
		sim[j,2] = actual[randbr[j,1],2];
	};

	////// Simulated Differences in Classes; 

	// generating vector of counts with each groomclass - brideclass value;
	diff = J(1, cols(simdif),0);
	for (j=1; j<=obs; j++) {; // looping over observations;
		dj = sim[j,1] - sim[j,2] + classesnm;
		diff[1, dj] = diff[1, dj] + 1;
	};

	// calculating total number of simulated couples with no missing class codes and 
		//filling proportions with each difference into simdif;
	nonmiss = rowsum(diff);
	simdif[i,.] = diff/nonmiss;	

};


////// Simulated Differences in Classes;

// sorting simulation results to extract lower and upper bounds for CI;
for (i=1; i<=cols(simdif); i++) {; //looping over grcl-brcl values;
	d = simdif[.,i];
	d = sort(d,1);
	simdif[.,i] = d;
};

// extracting appropriate elements for lower and upper bounds;
lowdif = simdif[floor(reps/40),.];
updif = simdif[floor(39*reps/40)+1,.];

condif = (lowdif',updif');

// saving mata matrix with difference results;
mata matsave condif condif, replace

// exiting mata;
end;

#delimit ;


************************************;
* making actual data comparable;

drop _all;
use tempmain2;

gen dist = clgr - clbr;
keep dist;
contract dist, percent(actual);
replace actual = actual/100;
drop _freq;

* making sure distance runs over the appropriate range;
sort dist;
save temp, replace;

drop _all;

matrix dist = J(2*`classesm1'+1,1,0);
forvalues i = -`classesm1'/`classesm1' {;
	matrix dist[`i'+`classesnm',1] = `i';
};
svmat dist;
rename dist1 dist;
sort dist;

merge dist using temp, unique;
drop _merge;
erase temp.dta;
mvencode actual, mv(0);

* retrieving simulation results generated before;

mata: mata matuse condif, replace;
mata: st_matrix("condif",condif);

matlist condif;
svmat condif;
rename condif1 lower;
rename condif2 upper;

* manually jittering lower end of CI so CI will appear on graph even if lower=upper;
replace lower = lower + (uniform() - 0.5)/10000;

gen negdist = -dist;

* Plotting histogram of confidence intervals and actual matches for social distance;
graph twoway (rcap lower upper negdist, lc(gs8)) (scatter actual negdist, m(x) mc(black) msize(large)), 
	xlabel(-`classesm1'(1)`classesm1', noticks) xtitle("bride's class minus groom's class") 
	ytitle("proportion") 
	legend(label(1 "95% confidence interval") 
	label(2 "observed"))
	graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white));
graph export figure4_panelA.tif,  replace;

capture erase condif.mmat;

drop _all;






*************************************************************************************;
* Panel B: Class defined by father's occupation 
*************************************************************************************;

capture erase condif.mmat;

local classesnm = 7; 
local classes = 8; 
local classesm1 = 6; 

clear mata;
use marriage_level, clear;
keep if year<=1914;

keep clfgr clfbr;
rename clfgr clgr;
rename clfbr clbr;
order clgr clbr;
drop if clgr>=. | clbr>=.;
save tempmain2, replace;


*** Simulation;

mata;

// Create a matrix called actual with groom classes in column 1 and bride classes in column 2;
actual = st_data(.,.);

// Define parameters for the simulation;
classesnm = 7; // the number of occupation classes excluding missing; //#####;
reps = 1000; //  the number of repetitions for the simulation; //#####;
obs = rows(actual); // the number of bride-groom pairs in each rep;

uniformseed(547543680);

// empty matrix to hold simulation proportions of grooms married to each type bride.  Rows are reps, 
	//cols are g1b1, g1b2,... g1b`classesnm', g2b1 etc;
simres = J(reps,classesnm^2,.);

// empty matrix to hold simulations proportions of class differences: simulated proportions of couples; 
	//where groom class - bride class = 0, +/-1,  +/-(#non-missing clases-1);
// rows are reps, cols are grcl-brcl = -(#non-missing classes-1), -(#non-missing classes-1)+1, etc;
simdif = J(reps,2*classesnm-1,.); // number of cols;

// main simulation loop;
for (i=1; i<=reps; i++) {; // looping over reps;
	randgr = ceil(obs*uniform(obs,1)); // matrix of random integers 1 to obs, to indicate which groom 
		//class to extract for each simulated groom;
	randbr = ceil(obs*uniform(obs,1));
	sim = J(obs,2,.); // matrix of missing values to hold simulated groom and bride classes;

	// fill in matrix sim with simulated groom and bride classes;
	for (j=1; j<=obs; j++) {; // looping over observations;
		sim[j,1] = actual[randgr[j,1],1];
		sim[j,2] = actual[randbr[j,1],2];
	};

	////// Simulated Differences in Classes; 

	// generating vector of counts with each groomclass - brideclass value;
	diff = J(1, cols(simdif),0);
	for (j=1; j<=obs; j++) {; // looping over observations;
		dj = sim[j,1] - sim[j,2] + classesnm;
		diff[1, dj] = diff[1, dj] + 1;
	};

	// calculating total number of simulated couples with no missing class codes and 
		//filling proportions with each difference into simdif;
	nonmiss = rowsum(diff);
	simdif[i,.] = diff/nonmiss;	

};


////// Simulated Differences in Classes;

// sorting simulation results to extract lower and upper bounds for CI;
for (i=1; i<=cols(simdif); i++) {; //looping over grcl-brcl values;
	d = simdif[.,i];
	d = sort(d,1);
	simdif[.,i] = d;
};

// extracting appropriate elements for lower and upper bounds;
lowdif = simdif[floor(reps/40),.];
updif = simdif[floor(39*reps/40)+1,.];

condif = (lowdif',updif');

// saving mata matrix with difference results;
mata matsave condif condif, replace

// exiting mata;
end;

#delimit ;


************************************;
* making actual data comparable;

drop _all;
use tempmain2;

gen dist = clgr - clbr;
keep dist;
contract dist, percent(actual);
replace actual = actual/100;
drop _freq;

* making sure distance runs over the appropriate range;
sort dist;
save temp, replace;

drop _all;

matrix dist = J(2*`classesm1'+1,1,0);
forvalues i = -`classesm1'/`classesm1' {;
	matrix dist[`i'+`classesnm',1] = `i';
};
svmat dist;
rename dist1 dist;
sort dist;

merge dist using temp, unique;
drop _merge;
erase temp.dta;
mvencode actual, mv(0);

* retrieving simulation results generated before;

mata: mata matuse condif, replace;
mata: st_matrix("condif",condif);

matlist condif;
svmat condif;
rename condif1 lower;
rename condif2 upper;

* manually jittering lower end of CI so CI will appear on graph even if lower=upper;
replace lower = lower + (uniform() - 0.5)/10000;

gen negdist = -dist;

* Plotting histogram of confidence intervals and actual matches for social distance;
graph twoway (rcap lower upper negdist, lc(gs8)) (scatter actual negdist, m(x) mc(black) msize(large)), 
	xlabel(-`classesm1'(1)`classesm1', noticks) xtitle("bride's father's class minus groom's father's class") 
	ytitle("proportion") 
	legend(label(1 "95% confidence interval") 
	label(2 "observed"))
	graphregion(fcolor(white) lcolor(white) ifcolor(white) ilcolor(white));
graph export figure4_panelB.tif,  replace;

capture erase condif.mmat;

drop _all;



