/* Created 27 November 2010.

This file uses the data marriage_level.dta and runs the marriage-level regressions for 
"Marrying Up: The role of sex ratio in assortative matching".
*/

#delimit ;

* set this folder path to the directory that contains the file marriage_level.dta;
local folder "~/Documents";

version 11.1;
set more off;
clear all;
cd "`folder'";
set matsize 800;
set memory 40M;
capture log close;
log using marriage_level.log, replace;



*************************************************************************************;
* Table A1 class distribution summary statistics and 
* Table A2: Assortative matching by class 
*************************************************************************************;

use marriage_level, clear;


* Table A1;

di _n "Tabulation of groom class distribution defined by own occupation pre and post war";
bys post: tab clgr;
di _n "Tabulation of bride class distribution defined by own occupation pre and post war";
bys post: tab clbr;

di _n "Tabulation of groom class distribution defined by father's occupation pre and post war";
bys post: tab clfgr;
di _n "Tabulation of bride class distribution defined by father's occupation pre and post war";
bys post: tab clfbr;


* Table A2;

di _n "Matching by class pre and post war";
bys post: tab clgr clbr, row;
lk;


*************************************************************************************;
* Table 3: Impact of male scarcity on assortative matching by class (OLS)
* Classes defined by own occupation
*************************************************************************************;

use marriage_level, clear;


* generating dependent variables;

gen classdiff = clbr - clgr;
label var classdiff "class difference";

gen mardn = 0 if clbr<=clgr & clgr<.;
replace mardn = 1 if clbr>clgr & clbr<.;
replace mardn = . if clgr==7;
label var mardn "married down";

gen lowbr = 1 if clbr<=7 & clbr>=5;
replace lowbr = 0 if clbr<5;
label var lowbr "low class bride";


* summary statistics on class defined by own occupation for Table A1;

di _n "Summary statistics on class defined by own occupation for Table A1";
bys post: sum classdiff mardn lowbr;


* generating scaled age variables;

gen agebrd = agebr/100;
gen agegrd = agegr/100;


* regressions using the full sample (columns 1-3);

di _n "Table 3, column 1";
xi: reg classdiff post_mortality post rural agebrd agegrd i.clgr i.depc, vce(cluster depc);		
di _n "Table 3, column 2";
xi: reg mardn post_mortality post rural agebrd agegrd i.clgr i.depc, vce(cluster depc);		
di _n "Table 3, column 3";
xi: reg lowbr post_mortality post rural agebrd agegrd i.clgr i.depc, vce(cluster depc);		


* regressions excluding class 1 and 2 grooms (columns 4-6);

di _n "Table 3, column 4";
xi: reg classdiff post_mortality post rural agebrd agegrd i.clgr i.depc if clgr>=3, vce(cluster depc);		
di _n "Table 3, column 5";
xi: reg mardn post_mortality post rural agebrd agegrd i.clgr i.depc if clgr>=3, vce(cluster depc);		
di _n "Table 3, column 6";
xi: reg lowbr post_mortality post rural agebrd agegrd i.clgr i.depc if clgr>=3, vce(cluster depc);		



*************************************************************************************;
* Table 4: Impact of male scarcity on assortative matching by class (OLS)
* Alternative definitions of class
* Plus Table A4: Class imputation regressions
*************************************************************************************;

use marriage_level, clear;


* generating dependent variables for classes defined by father's occupation;

gen classdiff = clfbr - clfgr;
label var classdiff "class difference (father's occ)";

gen mardn = 0 if clfbr<=clfgr & clfgr<.;
replace mardn = 1 if clfbr>clfgr & clfbr<.;
replace mardn = . if clfgr==7;
label var mardn "married down (father's occ)";

gen lowbr = 1 if clfbr<=7 & clfbr>=5;
replace lowbr = 0 if clfbr<5;
label var lowbr "low class bride (father's occ)";


* summary statistics on class defined by father's occupation for Table A1;

di _n "Summary statistics on class defined by father's occupation for Table A1";
bys post: sum classdiff mardn lowbr;


* generating scaled age variables;

gen agebrd = agebr/100;
gen agegrd = agegr/100;


* regressions using classes defined by father's occupation (columns 1-3);

di _n "Table 4, column 1";
xi: reg classdiff post_mortality post rural agebrd agegrd i.clfgr i.depc, vce(cluster depc);		
di _n "Table 4, column 2";
xi: reg mardn post_mortality post rural agebrd agegrd i.clfgr i.depc, vce(cluster depc);		
di _n "Table 4, column 3";
xi: reg lowbr post_mortality post rural agebrd agegrd i.clfgr i.depc, vce(cluster depc);		

drop classdiff mardn lowbr;


* generating imputed bride and groom classes using background information, for Table 4 columns 4-6;

* city size dummies;
xi i.city, prefix(C) noomit;
drop Ccity_4;

* Bride's father's class dummies for 7 non-missing categories;
xi i.clfbr, prefix(F) noomit;
mvencode Fclfbr*, mv(0) override;

* Bride's mother's class dummies for 7 non-missing categories;
xi i.clmbr, prefix(M) noomit;
mvencode Mclmbr*, mv(0) override;

* Dummy for bride's father's class is missing because he is dead;
gen Fdbr = (fdbr=="D");
replace Fdbr = 0 if clfbr<=7;

* Dummy for bride's mother's class is missing because she is dead;
gen Mdbr = (mdbr=="D");
replace Mdbr = 0 if clmbr<=7;

* Dummy for bride's father has no occupation;
gen Fnooccbr = (clfbr==.a);

* Dummy for bride's mother has no occupation;
gen Mnooccbr = (clmbr==.a);

* rural interactions with bride's parents' class dummies;
forvalues i = 1/7 {;
	gen rFclfbr_`i' = rural*Fclfbr_`i';
	gen rMclmbr_`i' = rural*Mclmbr_`i';
};
gen rFdbr = rural*Fdbr;
gen rMdbr = rural*Mdbr;
gen rFnooccbr = rural*Fnooccbr;
gen rMnooccbr = rural*Mnooccbr;

* Groom's father's class dummies for 7 non-missing categories;
xi i.clfgr, prefix(G) noomit;
mvencode Gclfgr*, mv(0) override;

* Groom's mother's class dummies for 7 non-missing categories;
xi i.clmgr, prefix(N) noomit;
mvencode Nclmgr*, mv(0) override;

* Dummy for groom's father's class is missing because he is dead;
gen Fdgr = (fdgr=="D");
replace Fdgr = 0 if clfgr<=7;

* Dummy for groom's mother's class is missing because she is dead;
gen Mdgr = (mdgr=="D");
replace Mdgr = 0 if clmgr<=7;

* Dummy for groom's father has no occupation;
gen Fnooccgr = (clfgr==.a);

* Dummy for groom's mother has no occupation;
gen Mnooccgr = (clmgr==.a);

* rural interactions with groom's parents' class dummies;
forvalues i = 1/7 {;
	gen rGclfgr_`i' = rural*Gclfgr_`i';
	gen rNclmgr_`i' = rural*Nclmgr_`i';
};
gen rFdgr = rural*Fdgr;
gen rMdgr = rural*Mdgr;
gen rFnooccgr = rural*Fnooccgr;
gen rMnooccgr = rural*Mnooccgr;

* imputing bride's class (Table A4, first two columns);
xi: reg clbr Fclfbr* Mclmbr* Fdbr Mdbr Fnooccbr Mnooccbr rural rFclfbr* rMclmbr* rFdbr rMdbr rFnooccbr rMnooccbr
	Ccity* if post==0;
predict est_clbr, xb;

* imputing groom's class (Table A4, last two columns);
xi: reg clgr Gclfgr* Nclmgr* Fdgr Mdgr Fnooccgr Mnooccgr rural rGclfgr* rNclmgr* rFdgr rMdgr rFnooccgr rMnooccgr
	Ccity* if post==0;
predict est_clgr, xb;

* generating groom half-class dummies;
gen est_clgr_half = round(2*est_clgr)/2;


* generating dependent variables for classes imputed from background characteristics;

gen classdiff = est_clbr - est_clgr;
label var classdiff "class difference (imputed)";

gen mardn = 0 if est_clbr<= est_clgr & est_clgr <.;
replace mardn = 1 if est_clbr> est_clgr & est_clbr <.;
replace mardn = . if est_clgr==7;
label var mardn "married down (imputed)";

gen lowbr = 1 if est_clbr <=7 & est_clbr>=4.2;
replace lowbr = 0 if est_clbr <4.2;
label var lowbr "low class bride (imputed)";


* summary statistics on class imputed from background characteristics for Table A1;

di _n "Summary statistics on class imputed from background characteristics for Table A1";
bys post: sum classdiff mardn lowbr;


* regressions using classes imputed from background characteristics (columns 4-6);

di _n "Table 4, column 4";
xi: reg classdiff post_mortality post rural agebrd agegrd i.est_clgr_half i.depc, vce(cluster depc);		
di _n "Table 4, column 5";
xi: reg mardn post_mortality post rural agebrd agegrd i.est_clgr_half i.depc, vce(cluster depc);		
di _n "Table 4, column 6";
xi: reg lowbr post_mortality post rural agebrd agegrd i.est_clgr_half i.depc, vce(cluster depc);		



*************************************************************************************;
* Table 5: Impact of male scarcity on assortative matching by class (IV)
*************************************************************************************;

use marriage_level, clear;


* generating dependent variables for regressions with class defined by own occupation;

gen classdiff = clbr - clgr;
label var classdiff "class difference";

gen mardn = 0 if clbr<=clgr & clgr<.;
replace mardn = 1 if clbr>clgr & clbr<.;
replace mardn = . if clgr==7;
label var mardn "married down";

gen lowbr = 1 if clbr<=7 & clbr>=5;
replace lowbr = 0 if clbr<5;
label var lowbr "low class bride";


* generating scaled age variables;

gen agebrd = agebr/100;
gen agegrd = agegr/100;


* regressions using classes defined by own occupation (columns 1-3);

di _n "Table 5, column 1";
xi: ivregress 2sls classdiff post rural agebrd agegrd i.clgr i.depc (sr = post_mortality), 
	vce(cluster depc);
di _n "Table 5, column 2";
xi: ivregress 2sls mardn post rural agebrd agegrd i.clgr i.depc (sr = post_mortality), 
	vce(cluster depc);
di _n "Table 5, column 3";
xi: ivregress 2sls lowbr post rural agebrd agegrd i.clgr i.depc (sr = post_mortality), 
	vce(cluster depc);

drop classdiff mardn lowbr;


* generating dependent variables for regressions with class defined by father's occupation;

gen classdiff = clfbr - clfgr;
label var classdiff "class difference (father's occ)";

gen mardn = 0 if clfbr<=clfgr & clfgr<.;
replace mardn = 1 if clfbr>clfgr & clfbr<.;
replace mardn = . if clfgr==7;
label var mardn "married down (father's occ)";

gen lowbr = 1 if clfbr<=7 & clfbr>=5;
replace lowbr = 0 if clfbr<5;
label var lowbr "low class bride (father's occ)";


* regressions using classes defined by father's occupation (columns 4-6);

di _n "Table 5, column 4";
xi: ivregress 2sls classdiff post rural agebrd agegrd i.clfgr i.depc (sr = post_mortality), 
	vce(cluster depc);
di _n "Table 5, column 5";
xi: ivregress 2sls mardn post rural agebrd agegrd i.clfgr i.depc (sr = post_mortality), 
	vce(cluster depc);
di _n "Table 5, column 6";
xi: ivregress 2sls lowbr post rural agebrd agegrd i.clfgr i.depc (sr = post_mortality), 
	vce(cluster depc);
	
	
	
*************************************************************************************;
* Table 6: Impact of male scarcity on assortative matching by age (OLS)
*************************************************************************************;

use marriage_level, clear;

gen agediff = agebr - agegr;
label var agediff "age difference";

recode clbr (.a = 8) (.b = 9);
recode clgr (.b = 9);

di _n "Table 6, column 1";
xi: reg agediff post_mortality post rural i.clbr i.clgr i.depc if secmargr==0 & secmarbr==0, vce(cluster depc);			
di _n "Table 6, column 2";
xi: reg agegr post_mortality post rural i.clgr i.depc if secmargr==0, vce(cluster depc);			
di _n "Table 6, column 3";
xi: reg agebr post_mortality post rural i.clbr i.depc if secmarbr==0, vce(cluster depc);			


* summary statistics on age variables for Table A1;

replace agediff = . if secmargr!=0 | secmarbr!=0;
replace agegr = . if secmargr!=0;
replace agebr = . if secmarbr!=0;

di _n "Summary statistics on age variables for Table A1";
bys post: sum agediff agebr agegr;
kj;


*************************************************************************************;
* Table A5: Impact of male scarcity on assortative matching by class (OLS, no regional fixed effects)
*************************************************************************************;

use marriage_level, clear;


* generating dependent variables for regressions defining class by own occupation;

gen classdiff = clbr - clgr;
label var classdiff "class difference";

gen mardn = 0 if clbr<=clgr & clgr<.;
replace mardn = 1 if clbr>clgr & clbr<.;
replace mardn = . if clgr==7;
label var mardn "married down";

gen lowbr = 1 if clbr<=7 & clbr>=5;
replace lowbr = 0 if clbr<5;
label var lowbr "low class bride";


* generating scaled age variables;

gen agebrd = agebr/100;
gen agegrd = agegr/100;


* regressions defining class by own occupation (columns 1-3);

di _n "Table A5, column 1";
xi: reg classdiff post_mortality mortality post rural agebrd agegrd i.clgr, vce(cluster depc);		
di _n "Table A5, column 2";
xi: reg mardn post_mortality mortality post rural agebrd agegrd i.clgr, vce(cluster depc);		
di _n "Table A5, column 3";
xi: reg lowbr post_mortality mortality post rural agebrd agegrd i.clgr, vce(cluster depc);		

drop classdiff mardn lowbr;


* generating dependent variables for classes defined by father's occupation;

gen classdiff = clfbr - clfgr;
label var classdiff "class difference (father's occ)";

gen mardn = 0 if clfbr<=clfgr & clfgr<.;
replace mardn = 1 if clfbr>clfgr & clfbr<.;
replace mardn = . if clfgr==7;
label var mardn "married down (father's occ)";

gen lowbr = 1 if clfbr<=7 & clfbr>=5;
replace lowbr = 0 if clfbr<5;
label var lowbr "low class bride (father's occ)";


* regressions defining class by father's occupation (columns 1-3);

di _n "Table A5, column 4";
xi: reg classdiff post_mortality mortality post rural agebrd agegrd i.clfgr, vce(cluster depc);		
di _n "Table A5, column 5";
xi: reg mardn post_mortality mortality post rural agebrd agegrd i.clfgr, vce(cluster depc);		
di _n "Table A5, column 6";
xi: reg lowbr post_mortality mortality post rural agebrd agegrd i.clfgr, vce(cluster depc);		

drop classdiff mardn lowbr;


* generating imputed bride and groom classes using background information, for Table A5 columns 7-9;

* city size dummies;
xi i.city, prefix(C) noomit;
drop Ccity_4;

* Bride's father's class dummies for 7 non-missing categories;
xi i.clfbr, prefix(F) noomit;
mvencode Fclfbr*, mv(0) override;

* Bride's mother's class dummies for 7 non-missing categories;
xi i.clmbr, prefix(M) noomit;
mvencode Mclmbr*, mv(0) override;

* Dummy for bride's father's class is missing because he is dead;
gen Fdbr = (fdbr=="D");
replace Fdbr = 0 if clfbr<=7;

* Dummy for bride's mother's class is missing because she is dead;
gen Mdbr = (mdbr=="D");
replace Mdbr = 0 if clmbr<=7;

* Dummy for bride's father has no occupation;
gen Fnooccbr = (clfbr==.a);

* Dummy for bride's mother has no occupation;
gen Mnooccbr = (clmbr==.a);

* rural interactions with bride's parents' class dummies;
forvalues i = 1/7 {;
	gen rFclfbr_`i' = rural*Fclfbr_`i';
	gen rMclmbr_`i' = rural*Mclmbr_`i';
};
gen rFdbr = rural*Fdbr;
gen rMdbr = rural*Mdbr;
gen rFnooccbr = rural*Fnooccbr;
gen rMnooccbr = rural*Mnooccbr;

* Groom's father's class dummies for 7 non-missing categories;
xi i.clfgr, prefix(G) noomit;
mvencode Gclfgr*, mv(0) override;

* Groom's mother's class dummies for 7 non-missing categories;
xi i.clmgr, prefix(N) noomit;
mvencode Nclmgr*, mv(0) override;

* Dummy for groom's father's class is missing because he is dead;
gen Fdgr = (fdgr=="D");
replace Fdgr = 0 if clfgr<=7;

* Dummy for groom's mother's class is missing because she is dead;
gen Mdgr = (mdgr=="D");
replace Mdgr = 0 if clmgr<=7;

* Dummy for groom's father has no occupation;
gen Fnooccgr = (clfgr==.a);

* Dummy for groom's mother has no occupation;
gen Mnooccgr = (clmgr==.a);

* rural interactions with groom's parents' class dummies;
forvalues i = 1/7 {;
	gen rGclfgr_`i' = rural*Gclfgr_`i';
	gen rNclmgr_`i' = rural*Nclmgr_`i';
};
gen rFdgr = rural*Fdgr;
gen rMdgr = rural*Mdgr;
gen rFnooccgr = rural*Fnooccgr;
gen rMnooccgr = rural*Mnooccgr;

* imputing bride's class (Table A4, first two columns);
xi: reg clbr Fclfbr* Mclmbr* Fdbr Mdbr Fnooccbr Mnooccbr rural rFclfbr* rMclmbr* rFdbr rMdbr rFnooccbr rMnooccbr
	Ccity* if post==0;
predict est_clbr, xb;

* imputing groom's class (Table A4, last two columns);
xi: reg clgr Gclfgr* Nclmgr* Fdgr Mdgr Fnooccgr Mnooccgr rural rGclfgr* rNclmgr* rFdgr rMdgr rFnooccgr rMnooccgr
	Ccity* if post==0;
predict est_clgr, xb;

* generating groom half-class dummies;
gen est_clgr_half = round(2*est_clgr)/2;


* generating dependent variables for classes imputed from background characteristics;

gen classdiff = est_clbr - est_clgr;
label var classdiff "class difference (imputed)";

gen mardn = 0 if est_clbr<= est_clgr & est_clgr <.;
replace mardn = 1 if est_clbr> est_clgr & est_clbr <.;
replace mardn = . if est_clgr==7;
label var mardn "married down (imputed)";

gen lowbr = 1 if est_clbr <=7 & est_clbr>=4.2;
replace lowbr = 0 if est_clbr <4.2;
label var lowbr "low class bride (imputed)";


* regressions using classes imputed from background characteristics (columns 7-9);

di _n "Table A5, column 7";
xi: reg classdiff post_mortality mortality post rural agebrd agegrd i.est_clgr_half, vce(cluster depc);		
di _n "Table A5, column 8";
xi: reg mardn post_mortality mortality post rural agebrd agegrd i.est_clgr_half, vce(cluster depc);		
di _n "Table A5, column 9";
xi: reg lowbr post_mortality mortality post rural agebrd agegrd i.est_clgr_half, vce(cluster depc);



*************************************************************************************;
* Table A6: Impact of male scarcity on assortative matching by class (OLS equivalent of IV)
*************************************************************************************;

use marriage_level, clear;


* generating dependent variables for regressions with class defined by own occupation;

gen classdiff = clbr - clgr;
label var classdiff "class difference";

gen mardn = 0 if clbr<=clgr & clgr<.;
replace mardn = 1 if clbr>clgr & clbr<.;
replace mardn = . if clgr==7;
label var mardn "married down";

gen lowbr = 1 if clbr<=7 & clbr>=5;
replace lowbr = 0 if clbr<5;
label var lowbr "low class bride";


* generating scaled age variables;

gen agebrd = agebr/100;
gen agegrd = agegr/100;


* regressions using classes defined by own occupation (columns 1-3);

di _n "Table A6, column 1";
xi: reg classdiff sr post rural agebrd agegrd i.clgr i.depc, vce(cluster depc);
di _n "Table A6, column 2";
xi: reg mardn sr post rural agebrd agegrd i.clgr i.depc, vce(cluster depc);
di _n "Table A6, column 3";
xi: reg lowbr sr post rural agebrd agegrd i.clgr i.depc, vce(cluster depc);

drop classdiff mardn lowbr;


* generating dependent variables for classes defined by father's occupation;

gen classdiff = clfbr - clfgr;
label var classdiff "class difference (father's occ)";

gen mardn = 0 if clfbr<=clfgr & clfgr<.;
replace mardn = 1 if clfbr>clfgr & clfbr<.;
replace mardn = . if clfgr==7;
label var mardn "married down (father's occ)";

gen lowbr = 1 if clfbr<=7 & clfbr>=5;
replace lowbr = 0 if clfbr<5;
label var lowbr "low class bride (father's occ)";


* regressions using classes defined by father's occupation (columns 4-6);

di _n "Table A6, column 4";
xi: reg classdiff sr post rural agebrd agegrd i.clfgr i.depc, vce(cluster depc);
di _n "Table A6, column 5";
xi: reg mardn sr post rural agebrd agegrd i.clfgr i.depc, vce(cluster depc);
di _n "Table A6, column 6";
xi: reg lowbr sr post rural agebrd agegrd i.clfgr i.depc, vce(cluster depc);




